==> centreon-web-25.10.2.tar.gz: centreon-web-25.10.2/www/front_src/src/Configuration/AdditionnalConnectors/translatedLabels.ts <==
export const labelAdditionalConnectorConfiguration =
  'Additional Configurations';
export const labelName = 'Name';
export const labelType = 'Type';
export const labelDescription = 'Description';
export const labelCreator = 'Creator';
export const labelCreationDate = 'Creation date';
export const labelLastUpdate = 'Last update';
export const labelActions = 'Actions';
export const labelUpdateBy = 'Updated by';
export const labelDelete = 'Delete';
export const labelDuplicate = 'Duplicate';
export const labelMoreActions = 'More actions';
export const labelEditConnectorConfiguration = 'Edit connector configuration';
export const labelSelectAtLeastOneColumn =
  'At least one column must be selected';
export const labelSearch = 'Search';
export const labelAdd = 'Add';
export const labelMoreFilters = 'More filters';
export const labelClear = 'Clear';
export const labelPoller = 'Poller';
export const labelCancel = 'Cancel';
export const labelDeleteAdditionalConnectorConfiguration =
  'Delete additional configuration';
export const labelDeleteAdditionalConnectorDescription =
  'The {{name}} additional configuration will be permanently deleted.';
export const labelSomeConnectorsMayNotWorkAnymore =
  'The corresponding connectors will not work anymore.';
export const labelAdditionalConnectorDeleted =
  'Additional configuration deleted';
export const labelAdditionalConnectorDuplicated =
  'Additional configuration duplicated';
export const labelAdditionalConnectorCreated =
  'Additional configuration created';
export const labelAdditionalConnectorUpdated =
  'Additional configuration updated';
export const labelDuplicateConnectorConfiguration =
  'Duplicate connector configuration';
export const labelSave = 'Save';
export const labelNameMustBeMost = 'The name can be at most 50 characters long';
export const labelDescriptionMustBeMost =
  'The name can be at most 50 characters long';
export const labelNameMustBeAtLeast =
  'The name should be at least 3 characters long';
export const labelRequired = 'Required';

export const labelCreate = 'Create';
export const labelUpdate = 'Update';
export const labelSelectType = 'Select type';
export const labelSelectPollers = 'Select poller(s)';
export const labelPort = 'Port';
export const labelValue = 'Value';
export const labelPassword = 'Password';
export const labelAddParameter = 'Add parameter';
export const labelUrl = 'URL';
export const labelUsername = 'Username';
export const labelAddvCenterESX = 'Add vCenter/ESX';
export const labelRemoveVCenterESX = 'Remove vCenter/ESX';
export const labelAteastOnePollerIsRequired = 'At least one poller is required';
export const labelAtLeastOneVCenterIsRequired =
  'At least one vCenter is required';
export const labelMustBeAvalidURL = 'Please enter a valid URL or IP address';
export const labelInvalidPortNumber = 'Invalid port number';
export const labelVcenterNameMustBeUnique =
  'The name of the vCenter should be unique';

export const labelDoYouWantToQuitWithoutSaving =
  'Do you want to quit without saving the changes?';
export const labelYourFormHasUnsavedChanges =
  'Your form has unsaved changes. Do you want to quit the form without saving the changes?';
export const labelConfirm = 'Confirm';
export const labelParameters = 'Parameters';
export const labelParametersTooltip = 'Parameters tooltip';
export const labelGeneralInformation = 'General information';
export const labelSettings = 'Settings';
export const labelvCenterESX = 'vCenter/ESX';

export const labelWelcomeToAdditionalConfigurations =
  'Welcome to the additional configurations page';
export const labelPageDescription =
  'For some connectors, you must define on the poller the credentials required to access the monitored hosts. You can do it easily from here.';
export const labelAddAdditionalConfigurations = 'Add additional configurations';

export const labelAddAnAdditionalConfiguration =
  'Add an additional configuration';
export const labelModifyConnectorConfiguration =
  'Modify an additional configuration';

==> centreon-web-25.10.6.tar.gz: centreon-web-25.10.6/www/front_src/src/Configuration/AdditionnalConnectors/translatedLabels.ts <==
export const labelAdditionalConnectorConfiguration =
  'Additional Configurations';
export const labelName = 'Name';
export const labelType = 'Type';
export const labelDescription = 'Description';
export const labelCreator = 'Creator';
export const labelCreationDate = 'Creation date';
export const labelLastUpdate = 'Last update';
export const labelActions = 'Actions';
export const labelUpdateBy = 'Updated by';
export const labelDelete = 'Delete';
export const labelDuplicate = 'Duplicate';
export const labelMoreActions = 'More actions';
export const labelEditConnectorConfiguration = 'Edit connector configuration';
export const labelSelectAtLeastOneColumn =
  'At least one column must be selected';
export const labelSearch = 'Search';
export const labelAdd = 'Add';
export const labelMoreFilters = 'More filters';
export const labelClear = 'Clear';
export const labelPoller = 'Poller';
export const labelCancel = 'Cancel';
export const labelDeleteAdditionalConnectorConfiguration =
  'Delete additional configuration';
export const labelDeleteAdditionalConnectorDescription =
  'The {{name}} additional configuration will be permanently deleted.';
export const labelSomeConnectorsMayNotWorkAnymore =
  'The corresponding connectors will not work anymore.';
export const labelAdditionalConnectorDeleted =
  'Additional configuration deleted';
export const labelAdditionalConnectorDuplicated =
  'Additional configuration duplicated';
export const labelAdditionalConnectorCreated =
  'Additional configuration created';
export const labelAdditionalConnectorUpdated =
  'Additional configuration updated';
export const labelDuplicateConnectorConfiguration =
  'Duplicate connector configuration';
export const labelSave = 'Save';
export const labelNameMustBeMost = 'The name can be at most 50 characters long';
export const labelDescriptionMustBeMost =
  'The name can be at most 50 characters long';
export const labelNameMustBeAtLeast =
  'The name should be at least 3 characters long';
export const labelRequired = 'Required';

export const labelCreate = 'Create';
export const labelUpdate = 'Update';
export const labelSelectType = 'Select type';
export const labelSelectPollers = 'Select poller(s)';
export const labelPort = 'Port';
export const labelValue = 'Value';
export const labelPassword = 'Password';
export const labelAddParameter = 'Add parameter';
export const labelUrl = 'URL';
export const labelUsername = 'Username';
export const labelAddvCenterESX = 'Add vCenter/ESX';
export const labelRemoveVCenterESX = 'Remove vCenter/ESX';
export const labelAteastOnePollerIsRequired = 'At least one poller is required';
export const labelAtLeastOneVCenterIsRequired =
  'At least one vCenter is required';
export const labelMustBeAvalidURL = 'Please enter a valid URL or IP address';
export const labelInvalidPortNumber = 'Invalid port number';
export const labelVcenterNameMustBeUnique =
  'The name of the vCenter should be unique';

export const labelDoYouWantToQuitWithoutSaving =
  'Do you want to quit without saving the changes?';
export const labelYourFormHasUnsavedChanges =
  'Your form has unsaved changes. Do you want to quit the form without saving the changes?';
export const labelConfirm = 'Confirm';
export const labelParameters = 'Parameters';
export const labelParametersTooltip = 'Parameters tooltip';
export const labelGeneralInformation = 'General information';
export const labelSettings = 'Settings';
export const labelvCenterESX = 'vCenter/ESX';

export const labelWelcomeToAdditionalConfigurations =
  'Welcome to the additional configurations page';
export const labelPageDescription =
  'For some connectors, you must define on the poller the credentials required to access the monitored hosts. You can do it easily from here.';
export const labelAddAdditionalConfigurations = 'Add additional configurations';

export const labelAddAnAdditionalConfiguration =
  'Add an additional configuration';
export const labelModifyConnectorConfiguration =
  'Modify an additional configuration';

export const labelEditPassword = 'Edit password';
export const labelRevertToPreviousPassword = 'Revert to previous password';
